<?php
/*
  $Id: customer_testimonials.php, v2.4bs 17th Oct. 2016 auzStar (Dominic C.) $
  Customer Testimonials for osCommerce 2.3.4 bootstrap - v2.4bs

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2016 osCommerce

  Released under the GNU General Public License
*/

  require('includes/application_top.php');

  // Redirect user to home page if Admin has disabled Customer Testimonials mod
  // The user should not be able to get to this module in that state, but just in case
  // We check for it to prevent problems
  if (!defined('TESTIMONIAL_ACTIVE') || TESTIMONIAL_ACTIVE != 'Yes') {
    tep_redirect(tep_href_link('index.php'));
  }

  // Redirect user to login page if:
  // only registered users are permitted to view testimonials and user is not logged in
  if (TESTIMONIAL_REGISTERED_VIEW == "Registered Users Only" && !tep_session_is_registered('customer_id')) {
    $navigation->set_snapshot();
    tep_redirect(tep_href_link('login.php', '', 'SSL'));
  }

  require('includes/languages/' . $language . '/customer_testimonials.php');

  $testimonial_id = (isset($_GET['testimonial_id']) && tep_not_null($_GET['testimonial_id']) ? tep_db_prepare_input($_GET['testimonial_id']) : '');

  // prepare database query using factors below
  $testimonial_raw_data = "select testimonials_id, testimonials_title, testimonials_html_text, left(testimonials_html_text, 50) as part_testimonial_text, testimonials_name, testimonials_email, testimonials_location, testimonial_image, date_added, language_id from customer_testimonials where (testimonials_html_text IS NOT NULL and testimonials_html_text <> '')";

  if ($testimonial_id != '') {
    // only display a specific testimonial selected from the infobox
    $testimonial_raw_data .= " and testimonials_id = '" . (int)$testimonial_id . "'";
  } else {
    // display a list of testimonials that have been set active by admin and depending on the language setting
    $testimonial_raw_data .= " and status = 1";
	if (TESTIMONIAL_LANG_PREF == "User Language Only") {
      // display only local language testimonials
      $testimonial_raw_data .= " and language_id = '" . (int)$languages_id . "'";
      $no_testimonial_text = TEXT_NO_TESTIMONIALS_LANG; // message to display when there are no testimonials in user language (used in customer testimonial module)
	} else {
      // display all testimonials for all languages
      $testimonial_raw_data .= "";
      $no_testimonial_text = TEXT_NO_TESTIMONIALS; // message to display when there are no testimonials at all (used in customer testimonial module)
	}
    // when displaying a list of testimonials order by testimonials_id to display by the order created, with latest at top
    $testimonial_raw_data .= " order by testimonials_id DESC";
  }

  $testimonial_data_split = new splitPageResults($testimonial_raw_data, (TESTIMONIALS_MAX_DISPLAY > 0 ? TESTIMONIALS_MAX_DISPLAY : 5));

  $breadcrumb->add(NAVBAR_TITLE, tep_href_link('customer_testimonials.php'));

  $oscTemplate->addBlock('<link href="ext/modules/customer_testimonials.css" rel="stylesheet">' . "\n", 'header_tags');

  require('includes/template_top.php');
?>

<style> div#expander { display: none; } </style>

<div class="page-header">
  <h1><?php echo HEADING_TITLE; ?></h1>
</div>

<?php
  if ($messageStack->size('customer_testimonials') > 0) {
    echo $messageStack->output('customer_testimonials');
  }
?>

<div class="contentContainer">

  <div class="contentText">

<?php
  if (($testimonial_data_split->number_of_rows > 0) && ((PREV_NEXT_BAR_LOCATION == '1') || (PREV_NEXT_BAR_LOCATION == '3'))) {
?>

<div class="row">
  <div class="col-sm-6 pagenumber hidden-xs">
    <?php echo $testimonial_data_split->display_count(TEXT_DISPLAY_NUMBER_OF_TESTIMONIALS); ?>
  </div>
  <div class="col-sm-6">
    <div class="pull-right pagenav"><ul class="pagination"><?php echo $testimonial_data_split->display_links(MAX_DISPLAY_PAGE_LINKS, tep_get_all_get_params(array('page', 'info', 'x', 'y'))); ?></ul></div>
    <span class="pull-right"><?php echo TEXT_RESULT_PAGE; ?></span>
  </div>
</div>

<?php
  }

  $testimonial_data = tep_db_query($testimonial_data_split->sql_query);

  require('includes/modules/customer_testimonials.php');

  if (($testimonial_data_split->number_of_rows > 0) && ((PREV_NEXT_BAR_LOCATION == '2') || (PREV_NEXT_BAR_LOCATION == '3'))) {
?>

<div class="row">
  <div class="col-sm-6 pagenumber hidden-xs">
    <?php echo $testimonial_data_split->display_count(TEXT_DISPLAY_NUMBER_OF_TESTIMONIALS); ?>
  </div>
  <div class="col-sm-6">
    <div class="pull-right pagenav"><ul class="pagination"><?php echo $testimonial_data_split->display_links(MAX_DISPLAY_PAGE_LINKS, tep_get_all_get_params(array('page', 'info', 'x', 'y'))); ?></ul></div>
    <span class="pull-right"><?php echo TEXT_RESULT_PAGE; ?></span>
  </div>
</div>

<?php
  }
?>

    <br />

    <div class="buttonSet row">

<?php
  // if we're displaying a specific testimonial selected from the infobox, then display button to choose to display all testimonials
  if ($testimonial_id != '') {
?>

	  <div class="col-xs-12 col-sm-3"><?php echo tep_draw_button(TEXT_LINK_TESTIMONIALS, 'fa fa-angle-left', tep_href_link('customer_testimonials.php')); ?></div>

<?php
  }

  // Do not display the button to write testimonials if disabled
  // When not disabled, access to the write testimonials page is dependant on whether the admin setting is "All users" or "Registered users"
  // If on "Registered users", then users will need an account and be logged in to write testimonials so will be redirected to login page if not logged in, "All users" setting will allow all users to write testimonials whether they have an account or not
  if (TESTIMONIAL_REGISTERED_WRITE != "Disabled") {
?>

	  <div class="col-xs-12 col-sm-<?php echo ($testimonial_id != '' ? '9' : '12'); ?> text-right"><?php echo tep_draw_button(IMAGE_BUTTON_WRITE_TESTIMONIAL, 'fa fa-comment', tep_href_link('customer_testimonials_write.php', '', 'SSL'), 'primary', NULL, 'btn-success'); ?></div>

<?php
  }
?>

    </div>

    <br />

  </div>
</div>

<script type="text/javascript">
$(function(){
  var testimonial_count = 0;
  var expand_count = 0;

  function showCollapse() {
    $("span#expand").hide();
    $("span#collapse").show();
  }

  function showExpand() {
    $("span#collapse").hide();
    $("span#expand").show();
  }

  function showMore(el_id) {
    $("div#boxTestText_less"+el_id).hide();
    $("div#boxTestText_more"+el_id).show();
  }

  function showLess(el_id) {
    $("div#boxTestText_more"+el_id).hide();
    $("div#boxTestText_less"+el_id).show();
  }

  $("a.boxTestText_link").each(function() {
    text_link_id = $(this).attr('id');
    if ($("div#boxTestText_less"+text_link_id).hasClass('boxTestText')) {
      testimonial_count++;
    }
  });

  $("a.boxTestText_link").click(function(e) {
    e.preventDefault();
    text_link_id = $(this).attr('id')
    if ($("div#boxTestText_less"+text_link_id).hasClass('boxTestText')) {
     if ($("div#boxTestText_less"+text_link_id).css('display') != 'none') {
        showMore(text_link_id);
        expand_count++;
        if (expand_count == testimonial_count) {
          showCollapse();
        }
      } else {
        showLess(text_link_id);
        expand_count--;
        if (expand_count == 0) {
        showExpand();
        }
      }
    }
  });

  $("div#expander").click(function() {
    if ($("span#collapse").css('display') == 'none') {
      showCollapse();
      expand_count = testimonial_count;
      $("a.boxTestText_link").each(function() {
        text_link_id = $(this).attr('id')
        showMore(text_link_id);
      });
    } else {
      showExpand();
      expand_count = 0;
      $("a.boxTestText_link").each(function() {
        text_link_id = $(this).attr('id')
        showLess(text_link_id);
      });
    }
  }).mouseover(function() {
    $(this).css('cursor', 'pointer');
  }).mouseout(function() {
    $(this).css('cursor', 'default');
  }).on('selectstart', function (event) {
    event.preventDefault();
  });
  
  if (testimonial_count > 1) {
    $("div#expander").show();
  }
});

</script>

<?php
  require('includes/template_bottom.php');
  require('includes/application_bottom.php');
?>
