<?php
/*
  $Id: Module Box bm_testimonials.php, v2.4bs 17th Oct. 2016 auzStar (Dominic C.) $
  Customer Testimonials for osCommerce 2.3.4 bootstrap - v2.4bs

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2016 osCommerce

  Released under the GNU General Public License
*/

  class bm_testimonials {
    var $version;
    var $code;
    var $group;
    var $title;
    var $description;
    var $sort_order;
    var $enabled = false;
	var $delete_table = false;

    function __construct() {
      $this->version = '2.4';
      $this->code = get_class($this);
      $this->group = basename(dirname(__FILE__));

      $this->title = MODULE_BOXES_TESTIMONIALS_TITLE;
      $this->description = MODULE_BOXES_TESTIMONIALS_DESCRIPTION;

      if ( defined('MODULE_BOXES_TESTIMONIALS_STATUS') ) {
        $this->sort_order = MODULE_BOXES_TESTIMONIALS_SORT_ORDER;
        $this->enabled = (MODULE_BOXES_TESTIMONIALS_STATUS == 'True');
		$this->delete_table = (MODULE_BOXES_TESTIMONIALS_DELETE_TABLE == 'True');
        $this->group = ((MODULE_BOXES_TESTIMONIALS_CONTENT_PLACEMENT == 'Left Column') ? 'boxes_column_left' : 'boxes_column_right');
      }
    }

    function execute() {
      global $languages_id, $oscTemplate;

      // Display the testimonial infobox only if admin has turned on the mod
      // Also check to see if viewing is restricted to registered users only
      // or if admin settings indicate all users may view testimonials
      if ( (defined('TESTIMONIAL_ACTIVE') && TESTIMONIAL_ACTIVE == 'Yes') && ( ((TESTIMONIAL_REGISTERED_VIEW == "Registered Users Only") && (tep_session_is_registered('customer_id'))) || (TESTIMONIAL_REGISTERED_VIEW == "All Users") ) ) {

        // add the testimonials module box css to the document header
        $oscTemplate->addBlock('<link href="ext/modules/boxes/testimonials/bm_testimonials.css" rel="stylesheet">' . "\n", 'header_tags');

        // first we figure out how many Testimonials to get from the database depending on factors below (use $random_testimonials to prepare database query).
        // Also note that a maximum of 60 characters of the testimonial text is used to display in the infobox
        $random_testimonials = "select testimonials_id, testimonials_title, substring(testimonials_html_text, 1, 60) as text, testimonials_name, testimonial_image FROM customer_testimonials WHERE status = 1 and (testimonials_html_text IS NOT NULL and testimonials_html_text <> '')";

        // check language display preference
        if (TESTIMONIAL_LANG_PREF == "User Language Only") {
          // if limited to "User Language Only" we pick testimonials from local language testimonials only
          $random_testimonials .= "  AND language_id = '" . (int)$languages_id . "'";
          $no_testimonial_text = MODULE_BOXES_TESTIMONIALS_NO_TESTIMONIALS_LANG; // message to display when there are no testimonials in local language only
	    } else {
          // if not limited to "User Language Only" we pick testimonials from all the languages
          $random_testimonials .= "";
          $no_testimonial_text = MODULE_BOXES_TESTIMONIALS_NO_TESTIMONIALS; // message to display when there are no testimonials at all
        }

        // if Scrolling feature is active then limit the number of testimonials to the figure set in the module (and set defaults for scrolling)
	    if (MODULE_BOXES_TESTIMONIALS_SCROLL_MODE == "Scrolling") {
          $testimonials_scroll_trigger = (MODULE_BOXES_TESTIMONIALS_SCROLL_TRIGGER > 1 ? MODULE_BOXES_TESTIMONIALS_SCROLL_TRIGGER : 2); // minimum of 2 testimonials requiured
          $testimonials_limit = (MODULE_BOXES_TESTIMONIALS_SCROLL_LIMIT < $testimonials_scroll_trigger ? $testimonials_scroll_trigger : MODULE_BOXES_TESTIMONIALS_SCROLL_LIMIT); // maximum testimonials must be equal to or more than the scroll trigger
	    } else {
          $testimonials_limit = 1; // else limit to 1 static testimonial
	    }

        // order by rand() to get random testimonials and then limit the number of testimonials by the value set above
        $random_testimonials .= " ORDER BY rand() limit " . $testimonials_limit;
        $random_testimonial_query = tep_db_query($random_testimonials);

        // Count the resulting number of testimonials that matched the language(s) used in the query above
	    $testimonial_count = tep_db_num_rows($random_testimonial_query);

        // create Write Testimonial link, if not disabled
        // If not disabled, access to the write testimonials page is dependant on whether the admin setting is "All users" or "Registered users"
        // If on "Registered users", then users will need an account and be logged in to write testimonials so will be redirected to login page if not logged in, "All users" setting will allow all users to write testimonials whether they have an account or not
	    $testimonial_write_link = '';
	    if (TESTIMONIAL_REGISTERED_WRITE != "Disabled") {
	      $testimonial_write_link = '<div class="text-center" style="padding-top: 15px;"><a href="' . tep_href_link('customer_testimonials_write.php', '', 'SSL') . '">' . MODULE_BOXES_TESTIMONIALS_WRITE_TESTIMONIAL . '</a></div>';
	    }

        // Check to see if any testimonials exist
	    if ($testimonial_count == 0) {
          // if not then only display Write Testimonial link, if appliable
          // and message that no testimonials are available to view
          $testimonials_box_contents = '<p class="text-center">' . $no_testimonial_text . '</p>' . $testimonial_write_link ;
	    } else {

          // set default values for use in script further below
          $scroller_height = (MODULE_BOXES_TESTIMONIALS_SCROLL_HEIGHT > 0 ? MODULE_BOXES_TESTIMONIALS_SCROLL_HEIGHT : 200); // height of scroller in px set in admin or use default
          $scroller_pause = (MODULE_BOXES_TESTIMONIALS_SCROLL_PAUSE > 0 ? MODULE_BOXES_TESTIMONIALS_SCROLL_PAUSE*1000 : 5000); // pause time of scroller (1000 - 1 sec, admin enters in secs ie 2 = 2secs then multiply by 1000 for carousel interval option) set in admin or use default
          $scrolling_on = (MODULE_BOXES_TESTIMONIALS_SCROLL_MODE == 'Scrolling' ? 1 : 0); // scrolling on or else averything is static
          $no_auto_scroll = (MODULE_BOXES_TESTIMONIALS_SCROLL_NO_AUTO_SCROLL == 'True' ? 1 : 0); // if scrolling is on, only scroll using swipe or nav buttons or else also auto scroll
          $no_swiping = (MODULE_BOXES_TESTIMONIALS_SCROLL_NO_SWIPING == 'True' ? 1 : 0); // if scrolling is on, only nav buttons and auto scroll will operate, not swiping
          $jquery_mobile_active = (defined('MODULE_HEADER_TAGS_JQUERY_MOBILE_STATUS') && MODULE_HEADER_TAGS_JQUERY_MOBILE_STATUS == 'True' ? 1 : 0); // is the jQuery Mobile Javascript header tag module is loaded and active, if not don't allow swiping to be enabled

          $i = 0;
          $ct = '<div id="ctCarousel" class="carousel slide ' . (MODULE_BOXES_TESTIMONIALS_SCROLL_METHOD == 'Fade' ? 'carousel-fade' : '') . '">';
          $ct .= '<div class="carousel-inner">';

          // loop through testimonials from random list
          while ($random_testimonial = tep_db_fetch_array($random_testimonial_query)) {

            $ct .= '<div class="' . ($i == 0 ? 'active ' : '') . 'item">';
	        $ct .= '<div class="content_vAlign">';
	        $ct .= '<div onclick="document.location.href=\'' . tep_href_link('customer_testimonials.php', 'testimonial_id=' . $random_testimonial['testimonials_id']) . '\'; return false;" onmouseover="this.style.cursor=\'pointer\'">';

	        $ct .= (tep_not_null($random_testimonial['testimonials_title']) ? '<p class="text-center"><b>' . tep_output_string_protected($random_testimonial['testimonials_title']) . '</b></p>' : '');
	        $ct .= (tep_not_null($random_testimonial['testimonial_image']) ? '<p class="text-center"><a href="' . tep_href_link('customer_testimonials.php', 'testimonial_id=' . $random_testimonial['testimonials_id']) . '">' . tep_image('images/testimonials/' . $random_testimonial['testimonial_image'], tep_output_string_protected($random_testimonial['testimonials_title']), SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . '</a></p>' : '');
	        $ct .= '<p><a href="' . tep_href_link('customer_testimonials.php', 'testimonial_id=' . $random_testimonial['testimonials_id']) . '">' . tep_break_string(tep_output_string_protected($random_testimonial['text']), 15, '-<br />') . '...</a></p>';
	        $ct .= (tep_not_null($random_testimonial['testimonials_name']) ? '<p class="text-center"><b>' . TEXT_BY . '</b>' . tep_output_string_protected($random_testimonial['testimonials_name']) . '</p>' : '');

	        $ct .= '</div>';

            if (MODULE_BOXES_TESTIMONIALS_SCROLL_VIEW_BUTTON == 'True') {
              $ct .= '<p class="text-center">' .tep_draw_button(SMALL_IMAGE_BUTTON_VIEW, '', tep_href_link('customer_testimonials.php', 'testimonial_id=' . $random_testimonial['testimonials_id']), '', '', 'btn-success btn-sm') . '</p>';
            }

	        $ct .= '</div>';
            $ct .= '</div>';

            $i++;

            // If Scrolling is turned off (or if Scrolling is turned on but we don't have enough testimonials to trigger scrolling), then default to Static display
            // and just display 1 random testimonial
            if ( (MODULE_BOXES_TESTIMONIALS_SCROLL_MODE != "Scrolling") || ($testimonial_count < $testimonials_scroll_trigger) ||
                 (MODULE_BOXES_TESTIMONIALS_SCROLL_NO_AUTO_SCROLL == 'True' && MODULE_BOXES_TESTIMONIALS_SCROLL_NO_SWIPING == 'True' &&
                  MODULE_BOXES_TESTIMONIALS_SCROLL_NAV_BUTTONS == 'False' && MODULE_BOXES_TESTIMONIALS_SCROLL_SWIPE_ARROWS == 'False') ) break;

    	  }
          $ct .= '</div>';

          // Nav controls if enabled and more than 1 testimonial (also hidden if javascript disabled)
          if (MODULE_BOXES_TESTIMONIALS_SCROLL_MODE == 'Scrolling' && $testimonial_count > 1 && $testimonial_count >= $testimonials_scroll_trigger) {
            if (MODULE_BOXES_TESTIMONIALS_SCROLL_NAV_BUTTONS == 'True') {
              $ct .= '<div class="hidden-xs hidden-sm hidden-md text-center nav-buttons" style="height: 25px; padding-top: 3px;">';
              $ct .= '<a class="btn-sm btn-primary" href="#ctCarousel" data-slide="next"><i class="icon-white fa fa-angle-left"></i></a>';
              $ct .= '<a class="btn-sm btn-primary" href="#ctCarousel" data-slide="prev"><i class="icon-white fa fa-angle-right"></i></a>';
              $ct .= '</div>';
            }
            if (MODULE_BOXES_TESTIMONIALS_SCROLL_SWIPE_ARROWS == 'True') {
              $ct .= '<div class="hidden-lg swipe-arrows" style="width: 100%;">';
              $ct .= '<a href="#ctCarousel" data-slide="next"><i class="fa fa-angle-left pull-left" style="opacity: 0.3; font-size: 24px;" onmousedown="this.style.opacity=\'0.9\'" onmouseup="this.style.opacity=\'0.3\'"></i></a>';
              $ct .= '<a href="#ctCarousel" data-slide="prev"><i class="fa fa-angle-right pull-right" style="opacity: 0.3; font-size: 24px;" onmousedown="this.style.opacity=\'0.9\'" onmouseup="this.style.opacity=\'0.3\'"></i></a>';
              $ct .= '</div>';
            }
          }

          $ct .= '</div>';

  	      $testimonials_box_contents = $ct . $testimonial_write_link;
  	      $testimonials_box_contents .= '<noscript><style> #ctCarousel .content_vAlign { top: 0; -webkit-transform: translateY(0); -ms-transform: translateY(0); transform: translateY(0); } #ctCarousel div.nav-buttons, #ctCarousel div.swipe-arrows { display: none; } </style></noscript>';

          $testimonials_box_contents .= <<<EOD
<script>

function set_ctHeights(resize) {
  var resize = resize || false;
  var scroller = "#ctCarousel"; // the scrolling container
  var scroller_height = $scroller_height; // height of scroller set in admin or use default
  var maxHeight = 0;

  if (resize) {
    $(scroller+" div.item").height('auto'); // needed this for window resize
  }
  // get the biggest item height
  $(scroller+" div.item").each(function() {
    if ($(this).height() > maxHeight) {
      maxHeight = $(this).height();
    }
  });

  // if the biggest item height is greater than the admin setting height then set the new height of scroller to accomadate the biggest item
  if (maxHeight > scroller_height){
    scroller_height = maxHeight;
  }

  // set all items height the same, using either the biggest item height or the admin setting height, which ever is the greater
  $(scroller+" div.item").height(scroller_height+10);
  // set the "small device" swipe indicators near the bottom of scroll box
  if ($(scroller+" div.swipe-arrows").is(":visible")) {
    $(scroller+" div.swipe-arrows").css({"position": "absolute", "top": scroller_height-5+"px"});
  }
}

$(document).ready(function() {
  var scrolling_on = $scrolling_on; // scrolling on or else everything is static
  var no_swiping = $no_swiping; // if scrolling is on, only nav buttons and auto scroll will operate, not swiping
  var jquery_mobile_active = $jquery_mobile_active; // if the jQuery Mobile Javascript header tag module is loaded and active then allow swiping to be enabled

  if (scrolling_on) {
    var scroller_pause = $scroller_pause; // pause time of scroller set in admin or use default
    $("#ctCarousel.carousel").carousel({
      interval: scroller_pause
    });
    var no_auto_scroll = $no_auto_scroll; // if scrolling is on, only scroll using swipe or nav buttons or else also auto scroll
    if (no_auto_scroll) {
      $("#ctCarousel.carousel").carousel('pause');
    }
  }

  if (jquery_mobile_active) {
    if (!no_swiping) {
      $("#ctCarousel").swiperight(function() {
        $(this).carousel('prev');
      });
      $("#ctCarousel").swipeleft(function() {
        $(this).carousel('next');
      });
    }
  }

});

$(document).ready(function() {
  set_ctHeights();
});

$(window).resize(function() { // corrects each item size when resizing window otherwise items will be too small or too large inside box
  set_ctHeights(true);
});

</script>
EOD;

        } // jump here if there were no testimonials to display "no testimonials" message and "write testimonial" link

        ob_start();
        include('includes/modules/boxes/templates/testimonials.php');
        $data = ob_get_clean();

        $oscTemplate->addBlock($data, $this->group);

      }
    }

    function isEnabled() {
      return $this->enabled;
    }

    function check() {
      return defined('MODULE_BOXES_TESTIMONIALS_STATUS');
    }

    function install() {
      global $language;

      // create Customer Testimonials table if it doesn't exist
	  if (tep_db_num_rows(tep_db_query("SHOW TABLES LIKE 'customer_testimonials'")) < 1) {
        tep_db_query("
          CREATE TABLE customer_testimonials (
            testimonials_id int(11) NOT NULL AUTO_INCREMENT,
            testimonials_title varchar(64) DEFAULT NULL,
            testimonials_html_text longtext DEFAULT NULL,
            testimonials_name varchar(50) DEFAULT NULL,
            testimonials_email varchar(70) DEFAULT NULL,
            testimonials_location varchar(70) DEFAULT NULL,
            testimonial_image varchar(128) DEFAULT NULL,
            date_added datetime DEFAULT NULL,
            last_modified datetime DEFAULT NULL,
            language_id int(11) NOT NULL DEFAULT '1',
            status tinyint(1) NOT NULL DEFAULT '1',
            PRIMARY KEY (testimonials_id)
          ) CHARACTER SET utf8 COLLATE utf8_unicode_ci;
        ");
      }

      // install Testimonials Box Module configuration entries
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) values ('Module Version', 'MODULE_BOXES_TESTIMONIALS_VERSION', '" . $this->version . "', 'The version of this module that you are running', '6', '1', 'tep_cfg_ct_version_check', 'tep_cfg_disabled(', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) values ('Module Check', 'MODULE_BOXES_TESTIMONIALS_MODULE_INSTALL_TEST', '0', 'Confirms correct installation of module', '6', '2', 'tep_cfg_ct_module_check', 'tep_cfg_ct_module_check(', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Enable Customer Testimonials Module', 'MODULE_BOXES_TESTIMONIALS_STATUS', 'True', 'Do you want to add the module to your shop? (Ensure that you also \"Activate Customer Testimonials\" in \"Configuration->Customer Testimonials\")', '6', '3', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");
	  tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('<span style=\"color: red;\">Delete Customer Testimonials table when removing this module</span>', 'MODULE_BOXES_TESTIMONIALS_DELETE_TABLE', 'False', '<span style=\"color: red;\">When this module is removed, do you want to delete the Customer Testimonials table that was created during the installation of this module?<br><i>WARNING!: All the data in the table will be deleted.</i></span>', '6', '4', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Content Placement', 'MODULE_BOXES_TESTIMONIALS_CONTENT_PLACEMENT', 'Right Column', 'Should the module be loaded in the left or right column?', '6', '5', 'tep_cfg_select_option(array(\'Left Column\', \'Right Column\'), ', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Display Mode (Static or Scrolling)', 'MODULE_BOXES_TESTIMONIALS_SCROLL_MODE', 'Scrolling', 'Defines the display mode. Scroll testimonials inside the infobox or show static view (one at a time). Testimonials are chosen randomly.', '6', '6', 'tep_cfg_select_option(array(\'Static\', \'Scrolling\'), ', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Scrolling Method', 'MODULE_BOXES_TESTIMONIALS_SCROLL_METHOD', 'Scroll', 'When Display Mode is Scrolling, select whether to scroll or fade items in the Scroll Box', '6', '7', 'tep_cfg_select_option(array(\'Scroll\', \'Fade\'), ',now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Disable Auto Scroll', 'MODULE_BOXES_TESTIMONIALS_SCROLL_NO_AUTO_SCROLL', 'False', 'When Display Mode is Scrolling, set whether to disable auto scrolling/fading and allow swipe and navigation indicators only', '6', '8', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Disable Swiping', 'MODULE_BOXES_TESTIMONIALS_SCROLL_NO_SWIPING', 'True', 'When Display Mode is Scrolling, set whether to disable swiping. Navigation indicators will still operate, (NOTE: For swiping to work jQuery Mobile Javascript must be loaded)', '6', '9', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Scrolling box height (in pixels)', 'MODULE_BOXES_TESTIMONIALS_SCROLL_HEIGHT', '200', 'Set the height of the infobox, default: 200. (If set too small, the infobox height will be automatically adjusted to fit the largest scrolling testimonial. Note: Testimonial Infobox shows only part of the testimonial comments.)', '6', '10', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Scrolling pause time (in secs)', 'MODULE_BOXES_TESTIMONIALS_SCROLL_PAUSE', '5', 'Controls how long each Testimonial is paused for inside the infobox, before scrolling to the next one.  Smaller number = shorter time. default: 5', '6', '11', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Minimum number of testimonials for scrolling', 'MODULE_BOXES_TESTIMONIALS_SCROLL_TRIGGER', '5', 'Even if Scrolling display mode is active, the testimonials will not scroll unless there are at least this many testimonials available. (Minimum of 2 testimonials required)', '6', '12', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Maximum number of random testimonials to retrieve from database (Scrolling testimonials only)', 'MODULE_BOXES_TESTIMONIALS_SCROLL_LIMIT', '5', 'Defines the maximum number of testimonials which will be presented to the user on any page view. Applicable only if Scrolling display mode is active. (Will use the \"Minimum number of testimonials\" value if this value is less)', '6', '13', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Display View Button', 'MODULE_BOXES_TESTIMONIALS_SCROLL_VIEW_BUTTON', 'True', 'Display the View button (for current testimonial)', '6', '14', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Display Navigation Buttons', 'MODULE_BOXES_TESTIMONIALS_SCROLL_NAV_BUTTONS', 'True', 'When Display Mode is Scrolling, set whether to show the navigation buttons (for destkops etc.)', '6', '15', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Display Swipe Indicators', 'MODULE_BOXES_TESTIMONIALS_SCROLL_SWIPE_ARROWS', 'True', 'When Display Mode is Scrolling, set whether to show the swipe indicators (for smaller devices)', '6', '16', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Sort Order', 'MODULE_BOXES_TESTIMONIALS_SORT_ORDER', '0', 'Sort order of display. Lowest is displayed first.', '6', '17', now())");

      // this section is added for users who are updgrading, so that the previous manually installed Customer Testimonials config entries can be automatically removed before being upgraded to the new version (below) so that there are no duplicates created, and since there are some changes to the new config entries
      // runs the remove function but only to remove the previous Customer Testimonials config entries if they exist - hence "$remove_all = false" (It doesn't matter if run again in future, or if this is not an upgrade, since there will be nothing to remove. Config entries will now always be removed on module removal)
      $this->remove(false);

      // add new configuration group for Customer Testimonials
      $configuration_query = tep_db_query("select max(configuration_group_id) as configuration_group_id, max(sort_order) as sort_order from configuration_group");
      $configuration = tep_db_fetch_array($configuration_query);
      $configuration_group_id = $configuration['configuration_group_id']+1;
      $sort_order = $configuration['sort_order']+1;
      tep_db_query("insert into configuration_group values ('" . $configuration_group_id . "', 'Customer Testimonials', 'Customer Testimonials configuration', '" . $sort_order . "', '1')");

      // install Customer Testimonials configuration entries
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Activate Customer Testimonials module', 'TESTIMONIAL_ACTIVE', 'Yes', 'Turn the Customer Testimonials module on or off. (Also shows/hides Testimonials Infobox)<br>', '" . $configuration_group_id . "', '1', 'tep_cfg_select_option(array(\'Yes\', \'No\'), ', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Who may VIEW testimonials?', 'TESTIMONIAL_REGISTERED_VIEW', 'All Users', 'Choose who may view testimonials.<br>', '" . $configuration_group_id . "', '2', 'tep_cfg_select_option(array(\'Registered Users Only\', \'All Users\'), ', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Who may WRITE testimonials?', 'TESTIMONIAL_REGISTERED_WRITE', 'Registered Users Only', 'Choose which classes of users are allowed to write testimonials.<br>', '" . $configuration_group_id . "', '3', 'tep_cfg_select_option(array(\'Registered Users Only\', \'All Users\', \'Disabled\'), ', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Who may send EMAIL to testimonial authors?', 'TESTIMONIAL_EMAIL_AUTHOR', 'Disabled', 'Allow users to send emails to testimonial author. Set to only registered users, all store users, or no one (disabled)<br><br>WARNING: If active, <u>users will see author email address</u>!<br>', '" . $configuration_group_id . "', '4', 'tep_cfg_select_option(array(\'Registered Users Only\', \'All Users\', \'Disabled\'), ', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Permit image uploads by testimonial authors', 'TESTIMONIAL_IMAGE_ALLOW', 'No', 'Allow users to upload images when submitting a testimonial.<br>', '" . $configuration_group_id . "', '5', 'tep_cfg_select_option(array(\'Yes\', \'No\'), ', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Customers testimonials image width', 'TESTIMONIAL_IMAGE_WIDTH', '120', 'Set Customers testimonials image width.<br>', '" . $configuration_group_id . "', '6', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Set Admin Language Default (used for email)', 'TESTIMONIAL_ADMIN_EMAIL', '" . $language . "', 'Select the language you would like used to send you email notifications when customer testimonials are submitted. (Testimonial is still in customer language)<br>', '" . $configuration_group_id . "', '7', 'tep_cfg_testimonials_languages(', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Testimonials langugage display setting', 'TESTIMONIAL_LANG_PREF', 'User Language Only', 'Define how Testimonials are viewed, based on viewer language. If your site has multiple languages, you can allow your users to view testimonials written in all languages or limit their viewing to the language they are using in the store.<br>', '" . $configuration_group_id . "', '8', 'tep_cfg_select_option(array(\'User Language Only\', \'All Languages\'), ', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Number of testimonials per page', 'TESTIMONIALS_MAX_DISPLAY', '5', 'Maximum number of testimonials to display per page.<br>', '" . $configuration_group_id . "', '9', now())");
      tep_db_query("insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Set age to delete old testimonials', 'TESTIMONIALS_MAX_AGE', '365', 'When using the option to \"Delete old Testimonials\" in \"Tools->Testimonials Manager\", set the age here for the life of testimonials, in days. Testimonials older than this figure will be deleted. (0 or blank will remove the option).<br>', '" . $configuration_group_id . "', '10', now())");

    }

    function remove($remove_all = true) {
    
      // when module is being removed normally then everything can be removed
      // the only time that $remove_all is false is when installing this module, so that the Customer Testimonials config entries from previous version can be removed first if they exist
      if ($remove_all) {
      
        // remove Customer Testimonials table only if if delete table option is true
	    if ($this->delete_table == true) {
          tep_db_query("DROP TABLE customer_testimonials");
        }

        // remove Testimonials Box Module configuration entries
        tep_db_query("delete from configuration where configuration_key in ('" . implode("', '", $this->keys()) . "')");

      }

      // find and remove Customer Testimonials configuration entries if they exist
      $configuration_query = tep_db_query("select configuration_group_id from configuration where configuration_key = 'TESTIMONIAL_ACTIVE'");
      if (tep_db_num_rows($configuration_query)) {
        $configuration = tep_db_fetch_array($configuration_query);
        tep_db_query("delete from configuration_group where configuration_group_id = '" . $configuration['configuration_group_id'] . "'");
        tep_db_query("delete from configuration where configuration_group_id = '" . $configuration['configuration_group_id'] . "'");
      }

    }

    function keys() {
      return array('MODULE_BOXES_TESTIMONIALS_VERSION', 'MODULE_BOXES_TESTIMONIALS_MODULE_INSTALL_TEST', 'MODULE_BOXES_TESTIMONIALS_STATUS', 'MODULE_BOXES_TESTIMONIALS_DELETE_TABLE', 'MODULE_BOXES_TESTIMONIALS_CONTENT_PLACEMENT', 'MODULE_BOXES_TESTIMONIALS_SCROLL_MODE', 'MODULE_BOXES_TESTIMONIALS_SCROLL_METHOD', 'MODULE_BOXES_TESTIMONIALS_SCROLL_NO_AUTO_SCROLL', 'MODULE_BOXES_TESTIMONIALS_SCROLL_NO_SWIPING', 'MODULE_BOXES_TESTIMONIALS_SCROLL_HEIGHT', 'MODULE_BOXES_TESTIMONIALS_SCROLL_PAUSE', 'MODULE_BOXES_TESTIMONIALS_SCROLL_TRIGGER', 'MODULE_BOXES_TESTIMONIALS_SCROLL_LIMIT', 'MODULE_BOXES_TESTIMONIALS_SCROLL_VIEW_BUTTON', 'MODULE_BOXES_TESTIMONIALS_SCROLL_NAV_BUTTONS', 'MODULE_BOXES_TESTIMONIALS_SCROLL_SWIPE_ARROWS', 'MODULE_BOXES_TESTIMONIALS_SORT_ORDER');
    }
  } // end class

  // Checks/updates the module version number when only needing to over-write this file
  if (!function_exists('tep_cfg_ct_version_check')) {
    function tep_cfg_ct_version_check($current_version) {

      // When updating the module by overwriting this file with a new version of the file, this updates the version configuration entry without having to remove and reinstall the module.
      // When viewing this module in admin (after overwriting this file) you will have to refresh the page to see the new version number.
      $bm_testimonials = new bm_testimonials;
      if ($current_version != $bm_testimonials->version) {
        tep_db_query("update configuration set configuration_value = '" . $bm_testimonials->version . "' where configuration_key = 'MODULE_BOXES_TESTIMONIALS_VERSION'");
      }
      return $current_version;

    }
  }

  // Check whether the new files, folders and modifications for this module exist
  if (!function_exists('tep_cfg_ct_module_check')) {
    function tep_cfg_ct_module_check() {
      global $language;

      $new_files = array(
        DIR_FS_ADMIN . 'ajax_delete_testimonial_pi.php',
        DIR_FS_ADMIN . 'testimonials_manager.php',
        DIR_FS_ADMIN . 'includes/boxes/tools_testimonials_manager.php',
        DIR_FS_ADMIN . 'includes/languages/' . $language . '/testimonials_manager.php',
        DIR_FS_ADMIN . 'includes/languages/' . $language . '/modules/boxes/tools_testimonials_manager.php',
        DIR_FS_CATALOG . 'customer_testimonials.php',
        DIR_FS_CATALOG . 'customer_testimonials_write.php',
        DIR_FS_CATALOG . 'ext/modules/customer_testimonials.css',
        DIR_FS_CATALOG . 'ext/modules/boxes/testimonials/bm_testimonials.css',
        DIR_FS_CATALOG . 'includes/classes/upload.php',
        DIR_FS_CATALOG . 'includes/modules/customer_testimonials.php',
        DIR_FS_CATALOG . 'includes/modules/action_recorder/ar_testimonials_write.php',
        DIR_FS_CATALOG . 'includes/modules/boxes/templates/testimonials.php',
        DIR_FS_CATALOG . 'includes/languages/' . $language . '/customer_testimonials.php',
        DIR_FS_CATALOG . 'includes/languages/' . $language . '/customer_testimonials_admin_email.php',
        DIR_FS_CATALOG . 'includes/languages/' . $language . '/customer_testimonials_write.php',
        DIR_FS_CATALOG . 'includes/languages/' . $language . '/modules/boxes/bm_testimonials.php',
        DIR_FS_CATALOG . 'includes/languages/' . $language . '/modules/action_recorder/ar_testimonials_write.php'
      );

      $jquery_mobile_files = array(
        DIR_FS_CATALOG . 'ext/jquery/jquery.mobile.custom.min.js',
        DIR_FS_CATALOG . 'includes/modules/header_tags/ht_jquery_mobile.php',
        DIR_FS_CATALOG . 'includes/languages/' . $language . '/modules/header_tags/ht_jquery_mobile.php'
      );

      $new_folders = array(
        DIR_FS_CATALOG . 'images/testimonials'
      );

      $edited_file = DIR_FS_ADMIN . 'includes/functions/general.php';

      $new_table = 'customer_testimonials';

      $missing_files = '';
      $missing_jquery_files = '';
      $missing_folders = '';
      $missing_modifications = '';
      $missing_database = '';

      foreach ($new_files as $file) {
        if (!file_exists($file) || !is_file($file)) $missing_files .= '<br />' . $file;
      }
      foreach ($jquery_mobile_files as $file) {
        if (!file_exists($file) || !is_file($file)) $missing_jquery_files .= '<br />' . $file;
      }
      foreach ($new_folders as $folder) {
        if (!file_exists($folder) || !is_dir($folder)) $missing_folders .= '<br />' . $folder;
      }

      if (file_exists($edited_file)) {
        $file_array = file($edited_file);

        $mod_found = false;
        foreach ($file_array as $line) {
          if (trim($line) == 'function tep_cfg_testimonials_languages($value) {') {
            $mod_found = true;
            break;
          }
        }
        if (!$mod_found) {
          $missing_modifications .= '<br />' . $edited_file;
        }
      } else {
        $missing_modifications .= '<br />' . $edited_file;
      }

      // check for existence of Customer Testimonials table
	  if (tep_db_num_rows(tep_db_query("SHOW TABLES LIKE '" . $new_table . "'")) < 1) {
        $missing_database .= '<br />' . $new_table;
      }

      if ($missing_files == '' && $missing_jquery_files == '' & $missing_folders == '' && $missing_modifications == '' && $missing_database == '') {
        return tep_image('images/icons/tick.gif', '', '16', '16', 'style="margin-bottom: -3px;"') . ' ' . MODULE_BOXES_TESTIMONIALS_NEW_FILES_FOUND;
      } else {
        return tep_image('images/icons/cross.gif', '', '16', '16', 'style="margin-bottom: -3px;"') . ' <span style="color: red;">' . MODULE_BOXES_TESTIMONIALS_NEW_FILES_MISSING . '</span>' .
               ($missing_files != '' ? '<br />' . '<strong>' . MODULE_BOXES_TESTIMONIALS_FILES_MISSING_TITLE . '</strong>' . $missing_files : '') .
               ($missing_jquery_files != '' ? '<br />' . '<strong>' . MODULE_BOXES_TESTIMONIALS_JQUERY_MOBILE_MISSING_TITLE . '</strong>' . $missing_jquery_files : '') .
               ($missing_folders != '' ? '<br />' . '<strong>' . MODULE_BOXES_TESTIMONIALS_FOLDERS_MISSING_TITLE . '</strong>' . $missing_folders : '') .
               ($missing_modifications != '' ? '<br />' . '<strong>' . MODULE_BOXES_TESTIMONIALS_MODS_MISSING_TITLE . '</strong>' . $missing_modifications : '') .
               ($missing_database != '' ? '<br />' . '<strong>' . MODULE_BOXES_TESTIMONIALS_DB_MISSING_TITLE . '</strong>' . $missing_database : '');
      }

    }
  }

  // function to display a disabled field
  if(!function_exists('tep_cfg_disabled')) {
    function tep_cfg_disabled($value) {
      return tep_draw_input_field('configuration_value', $value, 'disabled');
    }
  }
